@@ -11,6 +11,7 @@ from pages.admin.views import traduction, get_content, sub_menu
 from pages.admin.views import list_pages_ajax
 from pages.admin.views import change_status, modify_content, delete_content
 from pages.admin.views import move_page
+from pages.admin.actions import export_pages_as_json, import_pages_from_json
 from pages.permissions import PagePermission
 from pages.http import auto_render
 import pages.widgets
@@ -19,7 +20,7 @@ from django.contrib import admin
 from django.utils.translation import ugettext as _, ugettext_lazy
 from django.utils.encoding import force_unicode
 from django.conf import settings as global_settings
-from django.http import HttpResponseRedirect
+from django.http import HttpResponseRedirect, Http404
 from django.contrib.admin.util import unquote
 from django.contrib.admin.sites import AlreadyRegistered
 if global_settings.USE_I18N:
@@ -38,7 +39,8 @@ class PageAdmin(admin.ModelAdmin):
     # these mandatory fields are not versioned
     mandatory_placeholders = ('title', 'slug')
     general_fields = ['title', 'slug', 'status', 'target',
-        'position', 'freeze_date']
+        'position', 'freeze_date', 'template', 'language',
+        'redirect_to', 'redirect_to_url']
 
     if settings.PAGE_USE_SITE_ID and not settings.PAGE_HIDE_SITES:
         general_fields.append('sites')
@@ -62,23 +64,18 @@ class PageAdmin(admin.ModelAdmin):
         general_fields.append('delegate_to')
         insert_point = general_fields.index('status') + 1
 
-    normal_fields = ['language']
     page_templates = settings.get_page_templates()
-    if len(page_templates) > 0:
-        normal_fields.append('template')
-    normal_fields.append('redirect_to')
-    normal_fields.append('redirect_to_url')
+
     fieldsets = (
         [_('General'), {
             'fields': general_fields,
             'classes': ('module-general',),
         }],
-        (_('Options'), {
-            'fields': normal_fields,
-            'classes': ('module-options',),
-        }),
     )
 
+    if settings.PAGE_EXPORT_ENABLED:
+        actions = [export_pages_as_json]
+
     class Media:
         css = {
             'all': [join(settings.PAGES_MEDIA_URL, path) for path in (
@@ -89,8 +86,8 @@ class PageAdmin(admin.ModelAdmin):
         js = [join(settings.PAGES_MEDIA_URL, path) for path in (
             'javascript/jquery.js',
             'javascript/jquery.rte.js',
-            'javascript/jquery.query.js',
             'javascript/pages.js',
+            'javascript/pages_list.js',
             'javascript/pages_form.js',
         )]
 
@@ -115,6 +112,12 @@ class PageAdmin(admin.ModelAdmin):
             url(r'^(?P<page_id>[0-9]+)/change-status/$',
                 change_status, name='page-change-status'),
         )
+        if settings.PAGE_IMPORT_ENABLED:
+            urlpatterns += patterns('',
+                url(r'^import-json/$',
+                    self.import_pages, name='import-pages-from-json'),
+            )
+
         urlpatterns += super(PageAdmin, self).urls
 
         return urlpatterns
@@ -247,7 +250,7 @@ class PageAdmin(admin.ModelAdmin):
 
         return form
 
-    def change_view(self, request, object_id, extra_context=None):
+    def change_view(self, request, object_id, form_url='', extra_context=None):
         """The ``change`` admin view for the
         :class:`Page <pages.models.Page>`."""
         language = get_language_from_request(request)
@@ -276,8 +279,10 @@ class PageAdmin(admin.ModelAdmin):
                 settings.PAGE_LANGUAGES if Content.objects.get_content(obj,
                                     l[0], "title") and l[0] != language]
         extra_context['page'] = obj
-        return super(PageAdmin, self).change_view(request, object_id,
-                                                        extra_context)
+
+        return super(PageAdmin, self).change_view(request, object_id, 
+            form_url=form_url, extra_context=extra_context)
+
 
     def add_view(self, request, form_url='', extra_context=None):
         """The ``add`` admin view for the :class:`Page <pages.models.Page>`."""
@@ -311,8 +316,8 @@ class PageAdmin(admin.ModelAdmin):
 
     def list_pages(self, request, template_name=None, extra_context=None):
         """List root pages"""
-        if not admin.site.has_permission(request):
-            return admin.site.login(request)
+        if not self.admin_site.has_permission(request):
+            return self.admin_site.login(request)
         language = get_language_from_request(request)
 
         query = request.POST.get('q', '').strip()
@@ -324,11 +329,12 @@ class PageAdmin(admin.ModelAdmin):
         else:
             pages = Page.objects.root()
         if settings.PAGE_HIDE_SITES:
-            pages = pages.filter(sites=settings.SITE_ID)
+            pages = pages.filter(sites=global_settings.SITE_ID)
 
         perms = PagePermission(request.user)
         context = {
             'can_publish': perms.check('publish'),
+            'can_import': settings.PAGE_IMPORT_ENABLED,
             'language': language,
             'name': _("page"),
             'pages': pages,
@@ -341,6 +347,12 @@ class PageAdmin(admin.ModelAdmin):
 
         return change_list
 
+    def import_pages(self, request):
+        if not self.has_add_permission(request):
+            return admin.site.login(request)
+
+        return import_pages_from_json(request)
+
 
 class PageAdminWithDefaultContent(PageAdmin):
     """
