@@ -3,7 +3,7 @@ import unittest
 from pages.tests.test_functionnal import FunctionnalTestCase
 from pages.tests.test_unit import UnitTestCase
 from pages.tests.test_regression import RegressionTestCase
-from pages.tests.test_pages_link import LinkTestCase
+#from pages.tests.test_pages_link import LinkTestCase
 from pages.tests.test_auto_render import AutoRenderTestCase
 
 def suite():
